@@ -76,11 +76,8 @@ class QLDBDriver:
 
         for id in ids:
             statement = f"FROM {table_name} WHERE {identifier} = {id[identifier]} REMOVE {attribute_name}"
-            
-            try:
-                self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
-            except:
-                pass
+
+            self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
 
 
     def list_tables(self):
@@ -97,10 +94,12 @@ class QLDBDriver:
         self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
 
 
-    def update_data(self, table_name, primary_key_field, primary_key_value,data):
+    def update_data(self, table_name, primary_key_field, primary_key_value, data):
+        raw_data = str(data).replace("None", "null")
+
         statement = f"""
             UPDATE {table_name} AS x 
-                SET x = {str(data)} 
+                SET x = {raw_data} 
             WHERE x.{primary_key_field} = {primary_key_value}"""
         
         self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
